# PyKrev: van Krevelen analysis and beyond

PyKrev is a Python 3 package to help with analysis of high resolution mass spectrometry data.

[**The User Guide can be accessed here**](https://github.com/Kzra/PyKrev/blob/master/docs/PyKrevUserGuide.md)

[**Making UpSet plots with PyKrev**](https://github.com/Kzra/PyKrev/blob/master/docs/UpSetplotswithPyKrev.md)

Please send any feedback or comments to ezra.kitson@ed.ac.uk

Last update: 20/11/2020

<img src="https://github.com/Kzra/PyKrev/blob/master/docs/Pykrev_blue.png" alt="PyKrev" width="650"/>